/**
 * collectd - src/rrdc.c
 * Copyright (C) 2008 Florian octo Forster
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; only version 2 of the License is applicable.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 *
 * Authors:
 *   Florian octo Forster <octo at verplant.org>
 **/

#include "rrdd.h"
#include "rrdc.h"

#include <libgen.h>

static void exit_usage (char *name)
{
  printf ("Usage: %s <command> [options]\n"
      "\n"
      "Commands handled by rrdc:\n"
      "  update\n"
      "  help\n"
      "\n"
      "All other commands are passed to rrdtool(1).\n"
      "\n", basename (name));
  exit (0);
} /* void exit_usage */

int main (int argc, char **argv)
{
  char *name = "rrdc";
  int status;

  if (argc > 0)
    name = argv[0];

  if ((argc < 2)
      || (strcmp (argv[1], "help") == 0))
    exit_usage (name);

  /* rrdc update <file> <value> [<value> ..] */
  if ((argc >= 4) && (strcmp (argv[1], "update") == 0))
  {
    status = rrdd_connect (/* path = */ NULL);
    if (status != 0)
    {
      fprintf (stderr, "rrdd_connect failed: %s\n",
          strerror (status));
      return (1);
    }

    status = rrdd_update (argv[2], argc - 3, (void *) (argv + 3));
    if (status < 0)
    {
      fprintf (stderr, "rrdd_update failed.\n");
      status = 1;
    }
    else if (status > 0)
    {
      fprintf (stderr, "rrdd_update failed: %s\n",
          strerror (status));
      status = 1;
    }

    rrdd_disconnect ();
    return (status);
  }
  else
  {
    fprintf (stdout, "RRDc %s  Copyright 2008 by Florian Forster "
        "<octo at verplant.org>\n\n",
        PACKAGE_VERSION);
    fflush (stdout);

    assert (argv[argc] == NULL);

    status = execvp ("rrdtool", argv);
    fprintf (stderr, "execv failed with status %i.\n", status);
    return (1);
  }
} /* int main */

/*
 * vim: set sw=2 sts=2 ts=8 et fdm=marker :
 */
